# HBTN-CLI

Automates the Creation of  all necessary files of a project. by supplying one or more URL.

<img src="https://github.com/maleksal/hbtn-cli/blob/main/demo.gif"  style="zoom:150%;" />

## Install

```bash
$ python3 -m pip install hbtn-cli
```



## Usage

```console
$ hbtn setup

$ hbtn fetch <project URL>

$ hbtn --help
Usage: hbtn [OPTIONS] COMMAND [ARGS]...

  Create all necessary files of a project. by supplying one or more URL.

Options:
  --help  Show this message and exit.

Commands:
  fetch  Fetch project files and creates them.
  setup  Create settings.ini.


```

